@@ -1,7 +1,7 @@
 package Net::Flotum;
 use strict;
 use 5.008_005;
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use warnings;
 use utf8;
@@ -12,7 +12,7 @@ use namespace::clean;
 use Net::Flotum::API::Charge;
 use Net::Flotum::API::Customer;
 use Net::Flotum::API::RequestHandler;
-
+use Log::Any;
 use Net::Flotum::Object::Customer;
 
 has 'logger'    => ( is => 'ro', builder => '_build_logger',    lazy => 1 );
@@ -27,8 +27,7 @@ sub _build_requester {
 }
 
 sub _build_logger {
-    require Net::Flotum::Logger::Log4perl;
-    Net::Flotum::Logger::Log4perl->new->logger;
+    Log::Any->get_logger;
 }
 
 sub _build_customer_api {
@@ -45,18 +44,19 @@ sub _build_charge_api {
 sub load_customer {
     my ( $self, %opts ) = @_;
 
+    my $lazy = 1 if exists $opts{lazy} && $opts{lazy};
     my $cus;
     if ( exists $opts{id} ) {
         $cus = Net::Flotum::Object::Customer->new(
             flotum => $self,
             id     => $opts{id}
         );
-        $cus->_load_from_id;
+        $cus->_load_from_id unless $lazy;
     }
     elsif ( exists $opts{remote_id} ) {
         $cus = Net::Flotum::Object::Customer->new(
             flotum => $self,
-            id     => 'this workaround is embarrassed'
+            id     => '_ID_IS_REQUIRED_'
         );
         $cus->_load_from_remote_id( $opts{remote_id} );
     }
@@ -80,10 +80,14 @@ sub new_customer {
 
 sub _new_charge {
     my $self = shift;
-
     return $self->charge_api->exec_new_charge(@_);
 }
 
+sub _update_customer {
+    my $self = shift;
+    return $self->customer_api->exec_update_customer(@_);
+}
+
 sub _payment_charge {
     my $self = shift;
 
@@ -171,6 +175,12 @@ Net-Flotum - use Flotum as your payment gateway
         default_address_neighbourhood => '...'
     );
 
+    # try to load field 'foobar' from $customer
+    $customer->foobar
+
+    # set customer new name
+    $customer->update( name => 'new name' )
+
     # returns a Net::Flotum::Object::Customer
     $customer = $flotum->load_customer(
 
@@ -179,6 +189,9 @@ Net-Flotum - use Flotum as your payment gateway
         # or via id
         id => '0b912879-7c7b-42a1-8f49-722f13b67ae6'
 
+        # lazy load (only works with `id`, lazy loading with `remote_id` is not supported)
+        lazy => 1
+
     );
 
     # returns a hash reference containing details for creating an credit card.
